@@ -1,6 +1,6 @@
 /* exm-application.c
  *
- * Copyright 2022 Matthew Jakeman
+ * Copyright 2022-2024 Matthew Jakeman <mjakeman26@outlook.co.nz>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,6 +14,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
 #include "exm-config.h"
@@ -42,14 +44,6 @@ exm_application_new (gchar *application_id,
                        NULL);
 }
 
-static void
-exm_application_finalize (GObject *object)
-{
-    ExmApplication *self = (ExmApplication *)object;
-
-    G_OBJECT_CLASS (exm_application_parent_class)->finalize (object);
-}
-
 static ExmWindow *
 get_current_window (GApplication *app)
 {
@@ -84,9 +78,6 @@ static void
 exm_application_activate (GApplication *app)
 {
     GtkWindow *window;
-    GdkDisplay *display;
-    GtkCssProvider *provider;
-    GtkIconTheme *icon_theme;
 
     /* It's good practice to check your parameters at the beginning of the
     * function. It helps catch errors early and in development instead of
@@ -94,15 +85,6 @@ exm_application_activate (GApplication *app)
     */
     g_assert (GTK_IS_APPLICATION (app));
 
-    display = gdk_display_get_default ();
-    provider = gtk_css_provider_new ();
-    gtk_css_provider_load_from_resource (provider, "/com/mattjakeman/ExtensionManager/style.css");
-    gtk_style_context_add_provider_for_display (display, GTK_STYLE_PROVIDER (provider),
-                                                GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-
-    icon_theme = gtk_icon_theme_get_for_display (display);
-    gtk_icon_theme_add_resource_path (icon_theme, "/com/mattjakeman/ExtensionManager/icons");
-
     window = GTK_WINDOW (get_current_window (app));
 
     /* Ask the window manager/compositor to present the window. */
@@ -156,8 +138,6 @@ exm_application_class_init (ExmApplicationClass *klass)
     GObjectClass *object_class = G_OBJECT_CLASS (klass);
     GApplicationClass *app_class = G_APPLICATION_CLASS (klass);
 
-    object_class->finalize = exm_application_finalize;
-
     /*
     * We connect to the activate callback to create a window when the application
     * has been launched. Additionally, this callback notifies us when the user
@@ -183,33 +163,26 @@ exm_application_show_about (GSimpleAction *action,
 
     window = gtk_application_get_active_window (GTK_APPLICATION (self));
 
-    about_dialog = adw_about_dialog_new_from_appdata ("/com/mattjakeman/ExtensionManager/com.mattjakeman.ExtensionManager.metainfo.xml",
+    about_dialog = adw_about_dialog_new_from_appdata (g_strdup_printf ("%s/com.mattjakeman.ExtensionManager.metainfo.xml", RESOURCE_PATH),
                                                       strstr (APP_ID, ".Devel") == NULL ? APP_VERSION : NULL);
 
     adw_about_dialog_set_version (ADW_ABOUT_DIALOG (about_dialog), APP_VERSION);
     adw_about_dialog_set_comments (ADW_ABOUT_DIALOG (about_dialog), _("Browse, install, and manage GNOME Shell Extensions."));
     adw_about_dialog_set_developers (ADW_ABOUT_DIALOG (about_dialog), authors);
     adw_about_dialog_set_translator_credits (ADW_ABOUT_DIALOG (about_dialog), _("translator-credits"));
-    adw_about_dialog_set_copyright (ADW_ABOUT_DIALOG (about_dialog), "© 2022 Matthew Jakeman");
-
-    // Dependency Attribution
-    adw_about_dialog_add_legal_section (ADW_ABOUT_DIALOG (about_dialog),
-                                        "text-engine",
-                                        "Copyright (C) 2022 Matthew Jakeman",
-                                        GTK_LICENSE_MPL_2_0,
-                                        NULL);
+    adw_about_dialog_set_copyright (ADW_ABOUT_DIALOG (about_dialog), "© 2022-2024 Matthew Jakeman");
 
 #if WITH_BACKTRACE
     adw_about_dialog_add_legal_section (ADW_ABOUT_DIALOG (about_dialog),
                                         "libbacktrace",
-                                        "Copyright (C) 2012-2016 Free Software Foundation, Inc.",
+                                        "© 2012-2016 Free Software Foundation, Inc.",
                                         GTK_LICENSE_BSD_3,
                                         NULL);
 #endif
 
     adw_about_dialog_add_legal_section (ADW_ABOUT_DIALOG (about_dialog),
                                         "blueprint",
-                                        "Copyright (C) 2021 James Westman",
+                                        "© 2021 James Westman",
                                         GTK_LICENSE_LGPL_3_0,
                                         NULL);
 
