@@ -1,10 +1,29 @@
+/* exm-comment-tile.c
+ *
+ * Copyright 2022-2024 Matthew Jakeman <mjakeman26@outlook.co.nz>
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * SPDX-License-Identifier: GPL-3.0-or-later
+ */
+
 #include "exm-comment-tile.h"
 
-#include <text-engine/format/import.h>
-#include <text-engine/ui/display.h>
-
 #include "exm-rating.h"
 
+#include "exm-config.h"
+
 struct _ExmCommentTile
 {
     GtkWidget parent_instance;
@@ -14,7 +33,7 @@ struct _ExmCommentTile
     GtkLabel *author;
     GtkLabel *author_badge;
     ExmRating *rating;
-    TextDisplay *display;
+    GtkLabel *date;
 };
 
 G_DEFINE_FINAL_TYPE (ExmCommentTile, exm_comment_tile, GTK_TYPE_WIDGET)
@@ -38,8 +57,12 @@ exm_comment_tile_new (ExmComment *comment)
 static void
 exm_comment_tile_finalize (GObject *object)
 {
+    GtkWidget *child;
     ExmCommentTile *self = (ExmCommentTile *)object;
 
+    child = gtk_widget_get_first_child (GTK_WIDGET (self));
+    gtk_widget_unparent (child);
+
     G_OBJECT_CLASS (exm_comment_tile_parent_class)->finalize (object);
 }
 
@@ -86,16 +109,21 @@ exm_comment_tile_constructed (GObject *object)
 
     g_return_if_fail (EXM_IS_COMMENT (self->comment));
 
-    TextFrame *frame;
+    GDateTime *datetime;
 
-    gchar *text;
+    gchar *date;
     g_object_get (self->comment,
-                  "comment", &text,
+                  "date", &date,
                   NULL);
 
-    frame = format_parse_html (text);
+    datetime = g_date_time_new_from_iso8601 (date, g_time_zone_new_utc ());
+    g_free (date);
 
-    g_object_set (self->display, "frame", frame, NULL);
+    if (datetime != NULL)
+    {
+      gtk_label_set_label (self->date, g_date_time_format (datetime, "%x"));
+      g_date_time_unref (datetime);
+    }
 
     G_OBJECT_CLASS (exm_comment_tile_parent_class)->constructed (object);
 }
@@ -121,12 +149,12 @@ exm_comment_tile_class_init (ExmCommentTileClass *klass)
 
     GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
-    gtk_widget_class_set_template_from_resource (widget_class, "/com/mattjakeman/ExtensionManager/exm-comment-tile.ui");
+    gtk_widget_class_set_template_from_resource (widget_class, g_strdup_printf ("%s/exm-comment-tile.ui", RESOURCE_PATH));
 
-    gtk_widget_class_bind_template_child (widget_class, ExmCommentTile, display);
     gtk_widget_class_bind_template_child (widget_class, ExmCommentTile, author);
     gtk_widget_class_bind_template_child (widget_class, ExmCommentTile, author_badge);
     gtk_widget_class_bind_template_child (widget_class, ExmCommentTile, rating);
+    gtk_widget_class_bind_template_child (widget_class, ExmCommentTile, date);
 
     gtk_widget_class_set_layout_manager_type (widget_class, GTK_TYPE_BIN_LAYOUT);
 }
