@@ -1,6 +1,6 @@
 /* exm-detail-view.c
  *
- * Copyright 2022 Matthew Jakeman <mjakeman26@outlook.co.nz>
+ * Copyright 2022-2024 Matthew Jakeman <mjakeman26@outlook.co.nz>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,6 +25,8 @@
 #include "exm-info-bar.h"
 #include "exm-comment-tile.h"
 #include "exm-comment-dialog.h"
+#include "exm-install-button.h"
+#include "exm-screenshot.h"
 
 #include "web/exm-data-provider.h"
 #include "web/exm-image-resolver.h"
@@ -36,6 +38,8 @@
 #include "exm-types.h"
 #include "exm-enums.h"
 
+#include "exm-config.h"
+
 #include <glib/gi18n.h>
 
 struct _ExmDetailView
@@ -48,16 +52,13 @@ struct _ExmDetailView
     ExmCommentProvider *comment_provider;
     GCancellable *resolver_cancel;
 
-  	GSimpleAction *zoom_in;
-    GSimpleAction *zoom_out;
-    GSimpleAction *zoom_reset;
-
     gchar *shell_version;
     gchar *uuid;
 
     AdwHeaderBar *header_bar;
     AdwWindowTitle *title;
     GtkStack *stack;
+    AdwStatusPage *error_status;
     GtkButton *ext_install;
     GtkLabel *ext_description;
     GtkImage *ext_icon;
@@ -74,6 +75,9 @@ struct _ExmDetailView
 
     AdwActionRow *link_homepage;
     gchar *uri_homepage;
+    AdwExpanderRow *links_donations;
+    gchar **uri_donations;
+    GList *donation_rows_list;
     AdwActionRow *link_extensions;
     gchar *uri_extensions;
     int pk;
@@ -97,14 +101,6 @@ exm_detail_view_new (void)
     return g_object_new (EXM_TYPE_DETAIL_VIEW, NULL);
 }
 
-static void
-exm_detail_view_finalize (GObject *object)
-{
-    ExmDetailView *self = (ExmDetailView *)object;
-
-    G_OBJECT_CLASS (exm_detail_view_parent_class)->finalize (object);
-}
-
 static void
 exm_detail_view_get_property (GObject    *object,
                               guint       prop_id,
@@ -293,6 +289,69 @@ install_remote (GtkButton     *button,
                                 "(sb)", self->uuid, warn);
 }
 
+static void
+delete_donation_rows (ExmDetailView *self)
+{
+    GtkWidget *row;
+
+    for (GList *iter = self->donation_rows_list; iter != NULL; iter = g_list_next (iter)) {
+        row = GTK_WIDGET (iter->data);
+        adw_expander_row_remove (self->links_donations, row);
+    }
+
+    g_list_free (self->donation_rows_list);
+    self->donation_rows_list = NULL;
+}
+
+static void
+new_donation_row (ExmDetailView *self,
+                  int            num_donation)
+{
+    GtkWidget *row;
+    GtkWidget *external_link_icon;
+
+    row = adw_action_row_new ();
+
+    adw_preferences_row_set_title (ADW_PREFERENCES_ROW (row), self->uri_donations[num_donation]);
+    gtk_list_box_row_set_activatable (GTK_LIST_BOX_ROW (row), TRUE);
+
+    gtk_actionable_set_action_name (GTK_ACTIONABLE (row), "detail.open-donation");
+    gtk_actionable_set_action_target_value (GTK_ACTIONABLE (row), g_variant_new_int32 (num_donation));
+
+    external_link_icon = gtk_image_new_from_icon_name ("external-link-symbolic");
+    gtk_widget_add_css_class (external_link_icon, "dim-label");
+    adw_action_row_add_suffix (ADW_ACTION_ROW (row), external_link_icon);
+
+    adw_expander_row_add_row (self->links_donations, row);
+
+    self->donation_rows_list = g_list_append (self->donation_rows_list, row);
+}
+
+static void
+update_donation_rows (ExmDetailView  *self,
+                      gchar         **donation_urls)
+{
+    gtk_widget_set_visible (GTK_WIDGET (self->links_donations), FALSE);
+    delete_donation_rows (self);
+
+    if (donation_urls == NULL || donation_urls[0] == NULL)
+        return;
+
+    self->uri_donations = g_new0 (gchar *, g_strv_length (donation_urls));
+
+    for (int i = 0; donation_urls[i] != NULL; i++)
+    {
+        self->uri_donations[i] = g_uri_resolve_relative (donation_urls[i],
+                                                         "",
+                                                         G_URI_FLAGS_NONE,
+                                                         NULL);
+        new_donation_row (self, i);
+    }
+
+    adw_expander_row_set_expanded (self->links_donations, FALSE);
+    gtk_widget_set_visible (GTK_WIDGET (self->links_donations), TRUE);
+}
+
 static void
 on_data_loaded (GObject      *source,
                 GAsyncResult *result,
@@ -305,13 +364,30 @@ on_data_loaded (GObject      *source,
     GList *version_iter;
     ExmShellVersionMap *version_map;
 
+    data = exm_data_provider_get_finish (EXM_DATA_PROVIDER (source), result, &error);
     self = EXM_DETAIL_VIEW (user_data);
 
-    if ((data = exm_data_provider_get_finish (EXM_DATA_PROVIDER (source), result, &error)) != FALSE)
+    if (error && error->code != 404)
+    {
+        // Filter 5xx status codes (server errors)
+        if (error->code / 100 == 5)
+            adw_status_page_set_description (self->error_status, _("Check <a href='https://status.gnome.org/'>GNOME infrastructure status</a> and try again later"));
+        else
+            adw_status_page_set_description (self->error_status, _("Check your network status and try again"));
+
+        gtk_stack_set_visible_child_name (self->stack, "page_error");
+
+        g_clear_error (&error);
+
+        return;
+    }
+
+    if (EXM_IS_SEARCH_RESULT (data))
     {
         gint pk, downloads;
         gboolean is_installed, is_supported;
         gchar *uuid, *name, *creator, *icon_uri, *screenshot_uri, *link, *description, *url;
+        gchar **donation_urls;
         g_object_get (data,
                       "uuid", &uuid,
                       "name", &name,
@@ -324,6 +400,7 @@ on_data_loaded (GObject      *source,
                       "pk", &pk,
                       "url", &url,
                       "downloads", &downloads,
+                      "donation_urls", &donation_urls,
                       NULL);
 
         adw_window_title_set_title (self->title, name);
@@ -334,6 +411,9 @@ on_data_loaded (GObject      *source,
         is_supported = exm_search_result_supports_shell_version (data, self->shell_version);
 
         gtk_image_set_from_icon_name (self->ext_icon, "puzzle-piece-symbolic");
+        gtk_widget_set_tooltip_text (GTK_WIDGET (self->ext_icon),
+                                     // Translators: '%s' = extension name
+                                     g_strdup_printf (_("%s Icon"), name));
         gtk_label_set_label (self->ext_title, name);
         gtk_label_set_label (self->ext_author, creator);
         gtk_label_set_label (self->ext_description, description);
@@ -363,6 +443,10 @@ on_data_loaded (GObject      *source,
 			gtk_widget_set_visible (GTK_WIDGET (self->ext_screenshot_popout_button), FALSE);
 
             queue_resolve_image (self, screenshot_uri, self->resolver_cancel, FALSE);
+
+            gtk_widget_set_tooltip_text (GTK_WIDGET (self->ext_screenshot),
+                                         // Translators: '%s' = extension name
+                                         g_strdup_printf (_("%s Screenshot"), name));
         }
         else
         {
@@ -382,6 +466,8 @@ on_data_loaded (GObject      *source,
                                                      G_URI_FLAGS_NONE,
                                                      NULL);
 
+        update_donation_rows (self, donation_urls);
+
         self->uri_extensions = g_uri_resolve_relative ("https://extensions.gnome.org/",
                                                        link,
                                                        G_URI_FLAGS_NONE,
@@ -434,7 +520,7 @@ on_data_loaded (GObject      *source,
         return;
     }
 
-    gtk_stack_set_visible_child_name (self->stack, "page_error");
+    gtk_stack_set_visible_child_name (self->stack, "page_empty");
 }
 
 void
@@ -481,6 +567,12 @@ open_link (ExmDetailView *self,
         uri = gtk_uri_launcher_new (self->uri_extensions);
     else if (strcmp (action_name, "detail.open-homepage") == 0)
         uri = gtk_uri_launcher_new (self->uri_homepage);
+    else if (strcmp (action_name, "detail.open-donation") == 0)
+    {
+        guint val;
+        g_variant_get (param, "i", &val);
+        uri = gtk_uri_launcher_new (self->uri_donations[val]);
+    }
     else
         g_critical ("open_link() invalid action: %s", action_name);
 
@@ -490,20 +582,13 @@ open_link (ExmDetailView *self,
 static void
 on_bind_manager (ExmDetailView *self)
 {
-    GListModel *user_ext_model;
-    GListModel *system_ext_model;
+    GListModel *ext_model;
 
     g_object_get (self->manager,
-                  "user-extensions", &user_ext_model,
-                  "system-extensions", &system_ext_model,
+                  "extensions", &ext_model,
                   NULL);
 
-    g_signal_connect_swapped (user_ext_model,
-                              "items-changed",
-                              G_CALLBACK (exm_detail_view_update),
-                              self);
-
-    g_signal_connect_swapped (system_ext_model,
+    g_signal_connect_swapped (ext_model,
                               "items-changed",
                               G_CALLBACK (exm_detail_view_update),
                               self);
@@ -548,7 +633,6 @@ exm_detail_view_class_init (ExmDetailViewClass *klass)
 {
     GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-    object_class->finalize = exm_detail_view_finalize;
     object_class->get_property = exm_detail_view_get_property;
     object_class->set_property = exm_detail_view_set_property;
 
@@ -570,11 +654,12 @@ exm_detail_view_class_init (ExmDetailViewClass *klass)
 
     GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
-    gtk_widget_class_set_template_from_resource (widget_class, "/com/mattjakeman/ExtensionManager/exm-detail-view.ui");
+    gtk_widget_class_set_template_from_resource (widget_class, g_strdup_printf ("%s/exm-detail-view.ui", RESOURCE_PATH));
 
     gtk_widget_class_bind_template_child (widget_class, ExmDetailView, header_bar);
     gtk_widget_class_bind_template_child (widget_class, ExmDetailView, title);
     gtk_widget_class_bind_template_child (widget_class, ExmDetailView, stack);
+    gtk_widget_class_bind_template_child (widget_class, ExmDetailView, error_status);
     gtk_widget_class_bind_template_child (widget_class, ExmDetailView, ext_icon);
     gtk_widget_class_bind_template_child (widget_class, ExmDetailView, ext_title);
     gtk_widget_class_bind_template_child (widget_class, ExmDetailView, ext_author);
@@ -585,6 +670,7 @@ exm_detail_view_class_init (ExmDetailViewClass *klass)
 	gtk_widget_class_bind_template_child (widget_class, ExmDetailView, ext_screenshot_popout_button);
     gtk_widget_class_bind_template_child (widget_class, ExmDetailView, ext_info_bar);
     gtk_widget_class_bind_template_child (widget_class, ExmDetailView, link_homepage);
+    gtk_widget_class_bind_template_child (widget_class, ExmDetailView, links_donations);
     gtk_widget_class_bind_template_child (widget_class, ExmDetailView, link_extensions);
     gtk_widget_class_bind_template_child (widget_class, ExmDetailView, scroll_area);
     gtk_widget_class_bind_template_child (widget_class, ExmDetailView, comment_box);
@@ -595,8 +681,9 @@ exm_detail_view_class_init (ExmDetailViewClass *klass)
     gtk_widget_class_bind_template_callback (widget_class, breakpoint_unapply_cb);
     gtk_widget_class_bind_template_callback (widget_class, screenshot_view_cb);
 
-    gtk_widget_class_install_action (widget_class, "detail.open-extensions", NULL, open_link);
-    gtk_widget_class_install_action (widget_class, "detail.open-homepage", NULL, open_link);
+    gtk_widget_class_install_action (widget_class, "detail.open-extensions", NULL, (GtkWidgetActionActivateFunc) open_link);
+    gtk_widget_class_install_action (widget_class, "detail.open-homepage", NULL, (GtkWidgetActionActivateFunc) open_link);
+    gtk_widget_class_install_action (widget_class, "detail.open-donation", "i", (GtkWidgetActionActivateFunc) open_link);
 }
 
 static void
@@ -604,6 +691,10 @@ exm_detail_view_init (ExmDetailView *self)
 {
     GtkAdjustment *adj;
 
+    g_type_ensure (EXM_TYPE_INSTALL_BUTTON);
+    g_type_ensure (EXM_TYPE_SCREENSHOT);
+    g_type_ensure (EXM_TYPE_INFO_BAR);
+
     gtk_widget_init_template (GTK_WIDGET (self));
 
     self->provider = exm_data_provider_new ();
