@@ -15,4 +15,8 @@ void
 exm_screenshot_view_set_screenshot (ExmScreenshotView *self,
                                     GdkPaintable      *paintable);
 
+void
+exm_screenshot_view_zoom (ExmScreenshotView *self,
+                          const char        *action_name);
+
 G_END_DECLS
