@@ -1,3 +1,23 @@
+/* exm-manager.c
+ *
+ * Copyright 2022-2024 Matthew Jakeman <mjakeman26@outlook.co.nz>
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * SPDX-License-Identifier: GPL-3.0-or-later
+ */
+
 #include "exm-manager.h"
 
 #include "exm-extension.h"
@@ -11,8 +31,7 @@ struct _ExmManager
     GObject parent_instance;
 
     ShellExtensions *proxy;
-    GListModel *user_ext_model;
-    GListModel *system_ext_model;
+    GListModel *ext_model;
 
     const gchar *shell_version;
     gboolean extensions_enabled;
@@ -24,8 +43,7 @@ G_DEFINE_FINAL_TYPE (ExmManager, exm_manager, G_TYPE_OBJECT)
 
 enum {
     PROP_0,
-    PROP_USER_EXTENSIONS,
-    PROP_SYSTEM_EXTENSIONS,
+    PROP_EXTENSIONS,
     PROP_EXTENSIONS_ENABLED,
     PROP_SHELL_VERSION,
     N_PROPS
@@ -48,14 +66,6 @@ exm_manager_new (void)
     return g_object_new (EXM_TYPE_MANAGER, NULL);
 }
 
-static void
-exm_manager_finalize (GObject *object)
-{
-    ExmManager *self = (ExmManager *)object;
-
-    G_OBJECT_CLASS (exm_manager_parent_class)->finalize (object);
-}
-
 static void
 exm_manager_get_property (GObject    *object,
                           guint       prop_id,
@@ -66,11 +76,8 @@ exm_manager_get_property (GObject    *object,
 
     switch (prop_id)
     {
-    case PROP_USER_EXTENSIONS:
-        g_value_set_object (value, self->user_ext_model);
-        break;
-    case PROP_SYSTEM_EXTENSIONS:
-        g_value_set_object (value, self->system_ext_model);
+    case PROP_EXTENSIONS:
+        g_value_set_object (value, self->ext_model);
         break;
     case PROP_SHELL_VERSION:
         g_value_set_string (value, self->shell_version);
@@ -329,10 +336,7 @@ exm_manager_get_by_uuid (ExmManager  *self,
 {
     ExmExtension *result = NULL;
 
-    if ((result = list_model_get_by_uuid (self->user_ext_model, uuid)) != NULL)
-        return result;
-
-    if ((result = list_model_get_by_uuid (self->system_ext_model, uuid)) != NULL)
+    if ((result = list_model_get_by_uuid (self->ext_model, uuid)) != NULL)
         return result;
 
     return NULL;
@@ -342,10 +346,7 @@ gboolean
 exm_manager_is_installed_uuid (ExmManager  *self,
                                const gchar *uuid)
 {
-    if (list_model_contains (self->user_ext_model, uuid))
-        return TRUE;
-
-    if (list_model_contains (self->system_ext_model, uuid))
+    if (list_model_contains (self->ext_model, uuid))
         return TRUE;
 
     return FALSE;
@@ -426,8 +427,7 @@ notify_extension_updates (ExmManager *self)
     // emits the 'updates-available' signal with the number of updates
     int n_updates = 0;
 
-    n_updates += list_model_get_number_of_updates (self->user_ext_model);
-    n_updates += list_model_get_number_of_updates (self->system_ext_model);
+    n_updates += list_model_get_number_of_updates (self->ext_model);
 
     g_info ("There are %d new updates available.", n_updates);
 
@@ -481,21 +481,13 @@ exm_manager_class_init (ExmManagerClass *klass)
 {
     GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-    object_class->finalize = exm_manager_finalize;
     object_class->get_property = exm_manager_get_property;
     object_class->set_property = exm_manager_set_property;
 
-    properties [PROP_USER_EXTENSIONS]
-        = g_param_spec_object ("user-extensions",
-                               "User Extensions List Model",
-                               "User Extensions List Model",
-                               G_TYPE_LIST_MODEL,
-                               G_PARAM_READABLE);
-
-    properties [PROP_SYSTEM_EXTENSIONS]
-        = g_param_spec_object ("system-extensions",
-                               "System Extensions List Model",
-                               "System Extensions List Model",
+    properties [PROP_EXTENSIONS]
+        = g_param_spec_object ("extensions",
+                               "Extensions List Model",
+                               "Extensions List Model",
                                G_TYPE_LIST_MODEL,
                                G_PARAM_READABLE);
 
@@ -536,7 +528,6 @@ static void
 parse_single_extension (ExmExtension **extension,
                         const gchar   *extension_uuid,
                         GVariantIter  *variant_iter,
-                        gboolean      *is_user,
                         gboolean      *is_uninstall_operation)
 {
     gchar *prop_name;
@@ -547,12 +538,14 @@ parse_single_extension (ExmExtension **extension,
     gchar *display_name = NULL;
     gchar *description = NULL;
     gboolean enabled = FALSE;
+    gboolean is_user = FALSE;
     gboolean has_prefs = FALSE;
     gboolean has_update = FALSE;
     gboolean can_change = TRUE;
     ExmExtensionState state;
     ExmExtensionType type;
     gchar *version = NULL;
+    gchar *version_name = NULL;
     gchar *error_msg = NULL;
 
     if (extension && *extension)
@@ -622,13 +615,17 @@ parse_single_extension (ExmExtension **extension,
             g_variant_get (prop_value, "d", &val);
             version = g_strdup_printf ("%d", (gint)val);
         }
+        else if (strcmp (prop_name, "version-name") == 0)
+        {
+            g_variant_get (prop_value, "s", &version_name);
+        }
         else if (strcmp (prop_name, "error") == 0)
         {
             g_variant_get (prop_value, "s", &error_msg);
         }
     }
 
-    *is_user = (type == EXM_EXTENSION_TYPE_PER_USER);
+    is_user = (type == EXM_EXTENSION_TYPE_PER_USER);
     *is_uninstall_operation = (state == EXM_EXTENSION_STATE_UNINSTALLED);
 
     g_object_set (*extension,
@@ -636,26 +633,28 @@ parse_single_extension (ExmExtension **extension,
                   "description", description,
                   "state", state,
                   "enabled", enabled,
-                  "is-user", *is_user,
+                  "is-user", is_user,
                   "has-prefs", has_prefs,
                   "has-update", has_update,
                   "can-change", can_change,
                   "version", version,
+                  "version_name", version_name,
                   "error-msg", error_msg,
                   NULL);
 
     g_free (uuid);
     g_free (display_name);
     g_free (description);
+    g_free (version);
+    g_free (version_name);
+    g_free (error_msg);
 }
 
 static void
-parse_extension_list (GVariant   *exlist,
-                      GListModel **user_ext_model,
-                      GListModel **system_ext_model)
+parse_extension_list (GVariant    *exlist,
+                      GListModel **ext_model)
 {
-    GListStore *user_ext_store;
-    GListStore *system_ext_store;
+    GListStore *ext_store;
 
     /* format: a{sa{sv}}
      * array of interfaces, where each interface is an array of properties
@@ -666,16 +665,14 @@ parse_extension_list (GVariant   *exlist,
     GVariantIter *iter, *iter2;
     gchar *exname;
 
-    user_ext_store = g_list_store_new (EXM_TYPE_EXTENSION);
-    system_ext_store = g_list_store_new (EXM_TYPE_EXTENSION);
+    ext_store = g_list_store_new (EXM_TYPE_EXTENSION);
 
     g_variant_get (exlist, "a{sa{sv}}", &iter);
     while (g_variant_iter_loop (iter, "{sa{sv}}", &exname, &iter2)) {
-        gboolean is_user;
         gboolean is_uninstall_operation;
         ExmExtension *extension = NULL;
 
-        parse_single_extension (&extension, exname, iter2, &is_user, &is_uninstall_operation);
+        parse_single_extension (&extension, exname, iter2, &is_uninstall_operation);
 
         if (is_uninstall_operation)
         {
@@ -683,12 +680,11 @@ parse_extension_list (GVariant   *exlist,
             continue;
         }
 
-        g_list_store_append ((is_user ? user_ext_store : system_ext_store), extension);
+        g_list_store_append (ext_store, extension);
     }
     g_variant_iter_free (iter);
 
-    *user_ext_model = G_LIST_MODEL (user_ext_store);
-    *system_ext_model = G_LIST_MODEL (system_ext_store);
+    *ext_model = G_LIST_MODEL (ext_store);
 }
 
 static void
@@ -706,13 +702,11 @@ update_extension_list (ExmManager *self)
     }
 
     // Unref object if exists
-    g_clear_object (&self->user_ext_model);
-    g_clear_object (&self->system_ext_model);
+    g_clear_object (&self->ext_model);
 
-    parse_extension_list (exlist, &self->user_ext_model, &self->system_ext_model);
+    parse_extension_list (exlist, &self->ext_model);
 
-    g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_USER_EXTENSIONS]);
-    g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_SYSTEM_EXTENSIONS]);
+    g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_EXTENSIONS]);
 
     queue_notify_extension_updates (self);
 }
@@ -734,7 +728,6 @@ on_state_changed (ShellExtensions *object,
                   ExmManager      *self)
 {
     ExmExtension *extension;
-    gboolean is_user;
     gboolean is_new;
     gboolean is_uninstall_operation;
     GListStore *list_store;
@@ -751,10 +744,10 @@ on_state_changed (ShellExtensions *object,
 
     GVariantIter *iter;
     g_variant_get (arg_state, "a{sv}", &iter);
-    parse_single_extension (&extension, arg_uuid, iter, &is_user, &is_uninstall_operation);
+    parse_single_extension (&extension, arg_uuid, iter, &is_uninstall_operation);
     g_variant_iter_free (iter);
 
-    list_store = G_LIST_STORE (is_user ? self->user_ext_model : self->system_ext_model);
+    list_store = G_LIST_STORE (self->ext_model);
 
     if (is_new)
     {
